
> [!graph|gallery]
> ![[<* analysis_name *>_cap_vs_cyc.png]]
> ![[<* analysis_name *>_efficiency.png]]
>
> ![[<* analysis_name *>_ir_drop.png]]
> ![[<* analysis_name *>_ir_rise.png]]

> [!graph]
> ![[<* analysis_name *>_v_vs_cap.png]]

> [!graph]
> ![[<* analysis_name *>_dq_dv_vs_v.png]]
